#
# spec file for package python-mpi4py
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if 0%{?sle_version} && 0%{?sle_version} < 150000
  %define mpiver  openmpi
%else
  %define mpiver  openmpi2
%endif
Name:           python-mpi4py
Version:        3.0.3
Release:        bp156.3.4
Summary:        MPI for Python
License:        BSD-2-Clause
URL:            https://bitbucket.org/mpi4py/mpi4py
Source:         https://files.pythonhosted.org/packages/source/m/mpi4py/mpi4py-%{version}.tar.gz
BuildRequires:  %{mpiver}
BuildRequires:  %{mpiver}-config
BuildRequires:  %{mpiver}-devel
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       %{mpiver}
Requires:       %{mpiver}-config
%python_subpackages

%description
This package provides Python bindings for the Message Passing
Interface (MPI) standard. It is implemented on top of the MPI-1/2/3
specification and exposes an API which grounds on the standard MPI-2
C++ bindings.

This package supports:
  + Communication of any picklable Python object
    * Point-to-point: send & receive
    * Collective: broadcast, scatter & gather, reductions
  + Communication of Python object exposing the Python buffer
    interface (NumPy arrays, builtin bytes/string/array objects)
    * Point-to-point: blocking/nonbloking/persistent send & receive
    * Collective: broadcast, block/vector scatter & gather, reductions
  + Process groups and communication domains
    * Creation of new intra/inter communicators
    * Cartesian & graph topologies
  + Parallel input/output:
    * read & write
    * blocking/nonbloking & collective/noncollective
    * individual/shared file pointers & explicit offset
  + Dynamic process management
    * spawn & spawn multiple
    * accept/connect
    * name publishing & lookup
  + One-sided operations
    * remote memory access: put, get, accumulate
    * passive target syncronization: start/complete & post/wait
    * active target syncronization: lock & unlock

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}
Requires:       %{name}-common-devel = %{version}
Requires:       python-devel

%description    devel
Development libraries and headers needed to build packages using %{name}.

%package     -n %{name}-common-devel
Summary:        Shared development files for %{name}
Requires:       %{mpiver}-devel
Provides:       %{python_module mpi4py-common-devel = %{version}}

%description -n %{name}-common-devel
Development libraries and headers needed to build packages using %{name}
for both python2 and python3.

You normally do not need to install this directly, it will be pulled in by
the python-specific devel package.

%package     -n %{name}-doc
Summary:        Documentation for %{name}
Provides:       %{python_module mpi4py-doc = %{version}}

%description -n %{name}-doc
Documentation files and demos for %{name}.

%prep
%setup -q -n mpi4py-%{version}
rm demo/*/runtests.bat docs/source/usrman/make.bat
sed -i 's/\r$//' docs/usrman/objects.inv

%build
source %{_libdir}/mpi/gcc/%{mpiver}/bin/mpivars.sh

export CFLAGS="%{optflags} -fno-strict-aliasing"
export LANG=en_US.UTF-8
%{python_build --force}

%install
export LANG=en_US.UTF-8
%python_install

# De-duplicate includes and also put them in a more generally-accessible location.
mkdir -p %{buildroot}/%{_includedir}
%python_expand cp -r %{buildroot}%{$python_sitearch}/mpi4py/include/mpi4py %{buildroot}/%{_includedir}/
%python_expand rm -r %{buildroot}%{$python_sitearch}/mpi4py/include/mpi4py
%python_expand ln -s %{_includedir}/mpi4py %{buildroot}%{$python_sitearch}/mpi4py/include/mpi4py

%python_expand %fdupes %{buildroot}%{$python_sitearch}

mkdir -p %{buildroot}%{_docdir}%{name}
cp -r docs %{buildroot}%{_docdir}%{name}/
cp -r demo %{buildroot}%{_docdir}%{name}/
%fdupes %{buildroot}%{_docdir}%{name}

mkdir -p %{buildroot}%{_rpmmacrodir}
cat >> %{buildroot}%{_rpmmacrodir}/macros.mpi4py <<EOL
mpi4py_mpi_ver %{mpiver}
EOL

%check
export PYTHONDONTWRITEBYTECODE=1
export LANG=en_US.UTF-8
export OMPI_MCA_rmaps_base_oversubscribe=yes
rm -rf build _build.*
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
rm -rf build _build.*
%{_libdir}/mpi/gcc/%{mpiver}/bin/mpiexec --use-hwthread-cpus --mca btl tcp,self -n 1  $python -B test/runtests.py -v --exclude="test_msgspec"
}

%files %{python_files}
%doc CHANGES.rst DESCRIPTION.rst README.rst
%license LICENSE.rst
%{python_sitearch}/mpi4py
%{python_sitearch}/mpi4py-%{version}-py*.egg-info
%exclude %{python_sitearch}/mpi4py/include/

%files %{python_files devel}
%license LICENSE.rst
%{python_sitearch}/mpi4py/include/

%files -n %{name}-common-devel
%license LICENSE.rst
%{_includedir}/mpi4py/
%{_rpmmacrodir}/macros.mpi4py

%files -n %{name}-doc
%license LICENSE.rst
%dir %{_docdir}%{name}
%{_docdir}%{name}/docs/
%{_docdir}%{name}/demo/

%changelog
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to 3.0.3
  * Regenerate Cython wrappers to support Python 3.8.
- Drop upstream-included fix_window_size.patch
* Sun Aug  4 2019 Todd R <toddrme2178@gmail.com>
- Add fix_window_size.patch
  Fixes unit tests
  See: https://bitbucket.org/mpi4py/mpi4py/issues/137/
* Wed Jul 31 2019 Todd R <toddrme2178@gmail.com>
- Update to 3.0.2
  * Bug fixes:
    + Fix handling of readonly buffers in support for Pytho
    2 legacy buffer interface. The issue triggers only when using
    a buffer-like object that is readonly and does not export
    the new Python 3 buffer interface.
    + Fix build issues with Open MPI 4.0.x series related to
    removal of many MPI-1 symbols deprecated in MPI-2 and removed
    in MPI-3.
    + Minor documentation fixes.
* Wed Feb 27 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Use openmpi2 for releases that support it.
* Mon Feb 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.1:
  * Bug fixes:
    + Fix ``Comm.scatter()`` and other collectives corrupting input send
    list. Add safety measures to prevent related issues in global
    reduction operations.
    + Fix error-checking code for counts in ``Op.Reduce_local()``.
  * Enhancements:
    + Map size-specific Python/NumPy typecodes to MPI datatypes.
    + Allow partial specification of target list/tuple arguments in the
    various ``Win`` RMA methods.
    + Workaround for removal of ``MPI_{LB|UB}`` in Open MPI 4.0.
    + Support for Microsoft MPI v10.0.
- Add numpy as build dependency used in tests
* Thu Nov 15 2018 Todd R <toddrme2178@gmail.com>
- Use openmpi3 for releases that support it.
* Wed Jun 13 2018 toddrme2178@gmail.com
- Update to version 3.0.0
  * New features:
    + `mpi4py.futures`: Execute computations asynchronously using a pool
    of MPI processes. This package is based on ``concurrent.futures``
    from the Python standard library.
    + `mpi4py.run`: Run Python code and abort execution in case of
    unhandled exceptions to prevent deadlocks.
    + `mpi4py.bench`: Run basic MPI benchmarks and tests.
  * Enhancements:
    + Lowercase, pickle-based collective communication calls are now
    thread-safe through the use of fine-grained locking.
    + The ``MPI`` module now exposes a ``memory`` type which is a
    lightweight variant of the builtin ``memoryview`` type, but
    exposes both the legacy Python 2 and the modern Python 3 buffer
    interface under a Python 2 runtime.
    + The ``MPI.Comm.Alltoallw()`` method now uses ``count=1`` and
    ``displ=0`` as defaults, assuming that messages are specified
    through user-defined datatypes.
    + The ``Request.Wait[all]()`` methods now return ``True`` to match
    the interface of ``Request.Test[all]()``.
    + The ``Win`` class now implements the Python buffer interface.
  * Backward-incompatible changes:
    + The ``buf`` argument of the ``MPI.Comm.recv()`` method is
    deprecated, passing anything but ``None`` emits a warning.
    + The ``MPI.Win.memory`` property was removed, use the
    ``MPI.Win.tomemory()`` method instead.
    + Executing ``python -m mpi4py`` in the command line is now
    equivalent to ``python -m mpi4py.run``. For the former behavior,
    use ``python -m mpi4py.bench``.
    + Python 2.6 and 3.2 are no longer supported. The ``mpi4py.MPI``
    module may still build and partially work, but other pure-Python
    modules under the ``mpi4py`` namespace will not.
    + Windows: Remove support for legacy MPICH2, Open MPI, and DeinoMPI.
- Switch to recommended openmpi2 for distributions that support it.
* Wed Oct 25 2017 junghans@votca.org
- adapt to new openlmi package - source mpivars.h during build
* Tue May 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL.
- Package docs
* Wed Jan 25 2017 jengelh@inai.de
- Update description. Drop redundant %%clean.
* Tue Jan 24 2017 junghans@votca.org
- install LICENSE.rst as suggest in request#445611
* Sun Dec 11 2016 junghans@votca.org
- Update to version 2.0.0
  * Support for MPI-3 features.
  * Support for MPI-2 features not included in previous releases.
  * New scalable implementation of reduction operations for Python objects.
* Thu Oct 24 2013 toddrme2178@gmail.com
- Update to version 1.3.1
  * Regenerate C wrappers with Cython 0.19.1 to support Python 3.3.
  * Install ``*.pxd`` files in ``<site-packages>/mpi4py`` to ease the
    support for Cython's ``cimport`` statement in code requiring to
    access mpi4py internals.
  * As a side-effect of using Cython 0.19.1, ancient Python 2.3 is no
    longer supported. If you really need it, you can install an older
    Cython and run ``python setup.py build_src --force``.
* Tue May 22 2012 toddrme2178@gmail.com
- Update to version 1.3
- Add Python 3 package
* Sat Feb 25 2012 scorot@free.fr
- fix build for SLE-11
* Fri Jan  6 2012 toddrme2178@gmail.com
- Update to version 1.2.2
- Clean up spec file
- Switch to .changes file
* Tue May  5 2009 felix.richter2@uni-rostock.de
- Initial specfile generated by python distutils,
- adapted for SUSE Build Service
